<?php

/* --------------------------------------------------------------
   CatalogSelectWidgetAjaxController.inc.php 2017-09-11
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/


/**
 * Class CatalogSelectWidgetAjaxController
 *
 * This ajax controller is used by the catalog selector widget to fetch all products and categories in the shop.
 *
 * @category   System
 * @package    AdminHttpViewControllers
 * @extends    AdminHttpViewController
 */
class CatalogSelectWidgetAjaxController extends AdminHttpViewController
{
	/**
	 * @var CategoryReadService
	 */
	protected $categoryReadService;
	
	/**
	 * @var ProductReadServiceInterface
	 */
	protected $productReadService;
	
	/**
	 * @var LanguageCode
	 */
	protected $languageCode;
	
	
	/**
	 * Init
	 */
	public function init()
	{
		$this->categoryReadService = StaticGXCoreLoader::getService('CategoryRead');
		$this->productReadService  = StaticGXCoreLoader::getService('ProductRead');
		
		$languageProvider   = MainFactory::create('LanguageProvider', StaticGXCoreLoader::getDatabaseQueryBuilder());
		$this->languageCode = $languageProvider->getCodeById(new IdType((int)$_SESSION['languages_id']));
	}
	
	
	/**
	 * Returns the categorie tree of the shop.
	 *
	 * @return bool|\JsonHttpControllerResponse
	 * @throws \AuthenticationException
	 */
	public function actionGetCategoriesTree()
	{
		if(!$this->_isAdmin())
		{
			throw new AuthenticationException('No admin privileges. Please contact the administrator.');
		}
		
		$response = [
			'id'       => 0,
			'name'     => TEXT_TOP,
			'children' => $this->getCategoriesTreeData($withProducts = false),
		];
		
		return MainFactory::create('JsonHttpControllerResponse', $response);
	}
	
	
	/**
	 * Returns the categorie tree of the shop including all products.
	 *
	 * @return bool|\JsonHttpControllerResponse
	 * @throws \AuthenticationException
	 */
	public function actionGetProductsTree()
	{
		if(!$this->_isAdmin())
		{
			throw new AuthenticationException('No admin privileges. Please contact the administrator.');
		}
		
		$response = [
			'id'       => 0,
			'text'     => TEXT_TOP,
			'children' => $this->getCategoriesTreeData($withProducts = true),
			'products' => $this->getCategoryProducts(new IdType(0)),
		];
		
		return MainFactory::create('JsonHttpControllerResponse', $response);
	}
	
	
	/**
	 * Check if the customer is the admin.
	 *
	 * @return bool Is the customer the admin?
	 */
	protected function _isAdmin()
	{
		try
		{
			$this->validateCurrentAdminStatus();
			
			return true;
		}
		catch(LogicException $exception)
		{
			return false;
		}
	}
	
	
	/**
	 * Collects the data for the categories tree.
	 *
	 * @param bool $withProducts
	 * @param null $parentId
	 *
	 * @return array
	 */
	protected function getCategoriesTreeData($withProducts = false, $parentId = null)
	{
		$return     = [];
		$categories = $this->categoryReadService->getCategoryList($this->languageCode, $parentId);
		
		/**
		 * @var CategoryListItem $product
		 */
		foreach($categories->getArray() as $category)
		{
			if($withProducts)
			{
				$return[] = [
					'id'       => $category->getCategoryId(),
					'text'     => $category->getName(),
					'children' => $this->getCategoriesTreeData($withProducts, new IdType($category->getCategoryId())),
					'products' => $this->getCategoryProducts(new IdType($category->getCategoryId())),
				];
			}
			else
			{
				$return[] = [
					'id'       => $category->getCategoryId(),
					'text'     => $category->getName(),
					'children' => $this->getCategoriesTreeData($withProducts, new IdType($category->getCategoryId())),
				];
			}
		}
		
		return $return;
	}
	
	
	/**
	 * Collects the data of all products of a category.
	 *
	 * @param null $categoryId
	 *
	 * @return array
	 */
	protected function getCategoryProducts($categoryId = null)
	{
		$return   = [];
		$products = $this->productReadService->getProductList($this->languageCode, $categoryId);
		
		/**
		 * @var ProductListItem $product
		 */
		foreach($products->getArray() as $product)
		{
			$return[] = [
				'id'   => $product->getProductId(),
				'text' => $product->getName(),
			];
		}
		
		return $return;
	}
}